from app import db
from app.models.post import Post

class Program(Post):
    __tablename__ = 'program'
    __mapper_args__ = {'polymorphic_identity': __tablename__}

    # ID of underlying Post object
    id = db.Column(db.Integer, db.ForeignKey('post.id'), primary_key=True)

    # Program name
    title = db.Column(db.Unicode(128))

    # TODO: Category (games/utilities/lessons)
    # TODO: Tags
    # TODO: Compatible calculator models

    thread_id = db.Column(db.Integer,db.ForeignKey('thread.id'),nullable=False)
    thread = db.relationship('Thread', foreign_keys=thread_id,
        back_populates='owner_program')

    # TODO: Number of views, statistics, attached files, etc

    def __init__(self, author, title, thread):
        """
        Create a Program.

        Arguments:
        author -- post author (User, though only Members can post)
        title  -- program title (unicode string)
        thread -- discussion thread attached to the topic
        """

        Post.__init__(self, author)
        self.title = title
        self.thread = thread

    @staticmethod
    def from_topic(topic):
        p = Program(topic.author, topic.title, topic.thread)
        topic.promotion = p

    def delete(self):
        db.session.delete(self)

    def __repr__(self):
        return f'<Program: #{self.id} "{self.title}">'
